@@ -3,7 +3,7 @@ BEGIN {
   $App::Presto::Command::HTTP::AUTHORITY = 'cpan:BPHILLIPS';
 }
 {
-  $App::Presto::Command::HTTP::VERSION = '0.004';
+  $App::Presto::Command::HTTP::VERSION = '0.005';
 }
 
 # ABSTRACT: HTTP-related commands
@@ -30,13 +30,11 @@ sub install {
     $self->term->add_commands(
         {
             form => {
+                desc => "helper for formatting URL-encoded strings",
+                minargs => 1,
+                args => "some-key=some-value",
                 proc => sub {
-                    my @query;
-                    foreach my $kv (@_) {
-                        my ( $k, $v ) = split( /=/, $kv, 2 );
-                        push @query, $k, $v || '';
-                    }
-                    my $uri = $client->_append_query_params( '', @query );
+                    my $uri = $client->_append_query_params( '', @_ );
                     $uri =~ s{^\?}{};
                     print "$uri\n";
                   }
@@ -62,25 +60,35 @@ sub _mk_proc_for {
         if($method =~ m/^P/){
             warn " * no content-type header currently set\n" unless $client->get_header('Content-Type');
         }
+        my $out;
+        if(($out) = $_[-1] =~ /^>(.+)/){
+            pop @_;
+        }
         $client->$method(@_);
-        $self->handle_response($client);
+        $self->handle_response($client, $out);
     }
 }
 
 sub handle_response {
     my $self = shift;
     my $client = shift;
+    my $output_to = shift;
     my $response = $client->response;
     my $config = $self->config;
     if ( $config->get('verbose') ) {
         print _dump_request_response( $response->request, $response );
     }
     if ( $client->has_response_content ) {
-        if ( $config->get('deserialize_response') ) {
+        if($output_to){
+            warn " * sending output to $output_to\n";
+            open(my $out_fh, '>', $output_to) or die "unable to open $output_to for writing: $!";
+            print $out_fh $response->content;
+            close $out_fh or die "unable to close $output_to after writing: $!";
+        } elsif ( $config->get('deserialize_response') ) {
             my $data = $client->response_data;
-            print $self->pretty_print($data);
+            print ref $data ? $self->pretty_print($data) : "$data\n";
         } elsif ( !$config->get('verbose') ) {    # don't print just the content a second time...
-            print $response->decoded_content;
+            print readable_content($response);
             print "\n";
         }
     } elsif ( !$config->get('verbose') ) {
@@ -90,15 +98,30 @@ sub handle_response {
 
 sub _dump_request_response {
     my($request,$response) = @_;
-    return sprintf(<<'_OUT_', $request->as_string, $response->as_string);
+    return sprintf(<<'_OUT_', $request->headers->as_string, readable_content($request), $response->headers->as_string, readable_content($response));
 ----- REQUEST  -----
 %s
+%s
 ----- RESPONSE -----
 %s
+%s
 -----   END    -----
 _OUT_
 }
 
+sub readable_content {
+    my $message = shift;
+    return is_human_readable($message) ? $message->decoded_content : sprintf('[ %d bytes of binary data ]', $message->content_length || length($message->decoded_content));
+}
+
+sub is_human_readable {
+    my $message = shift;
+    return $message->content_type =~ m{\b(?:xml|^text|application/json)\b} || do {
+        my $content = substr($message->decoded_content, 0, 1000);
+        $content eq '' || (((my $tmp = $content) =~ tr/[:print:]//) / length($content) > 0.3);
+    };
+}
+
 sub help_categories {
     return {
         desc => 'Various HTTP verb commands',
@@ -117,7 +140,7 @@ App::Presto::Command::HTTP - HTTP-related commands
 
 =head1 VERSION
 
-version 0.004
+version 0.005
 
 =head1 AUTHOR
 
